local Reverse = string.find(GAMESTATE:GetPlayerState(pn):GetPlayerOptionsString("ModsLevel_Preferred"), "Reverse");

local rawMini = GAMESTATE:GetPlayerState(pn):GetCurrentPlayerOptions():Mini()
--Variable that scales back to 1 according to mini%. Works for both zoom and for some but not all coordinates
--Thanks to ecafree2 for this equation
local miniAdjustedScale = 1/(1-(rawMini/2))

--Table of girls to choose for the random girl function
girlTable = {
	"yukino",
	"yui",
	"iroha"
}

--Determine which stage girl textures are selected in metrics
if tostring(NOTESKIN:GetMetric("NoteskinPreferences","LeftGirl")) == "random" then
	--Randomly select texture from table above if "random" is set in metrics
	leftGirl = "Stage/stage " .. girlTable[math.random(1,3)]
else
	--Otherwise use the preference itself
	leftGirl = "Stage/stage " .. tostring(NOTESKIN:GetMetric("NoteskinPreferences","LeftGirl"))
end

if tostring(NOTESKIN:GetMetric("NoteskinPreferences","RightGirl")) == "random" then
	rightGirl = "Stage/stage " .. girlTable[math.random(1,3)]
else
	rightGirl = "Stage/stage " .. tostring(NOTESKIN:GetMetric("NoteskinPreferences","RightGirl"))
end


--Set stage borders to on/off depending on metrics
if tostring(NOTESKIN:GetMetric("NoteskinPreferences","StageBorderToggle")) == "off" then
	stageBorderActive = 0
else
	stageBorderActive = 1
end

--Set stage buttons to on/off depending on metrics
if tostring(NOTESKIN:GetMetric("NoteskinPreferences","StageButtonToggle")) == "off" then
	stageButtonActive = 0
else
	stageButtonActive = 1
end

local t = Def.ActorFrame{

--Notefield laser graphic
	Def.Sprite {
		Texture="Lasers/" .. tostring(NOTESKIN:GetMetric("NoteskinPreferences","LaserColor"));
		Frame0000=0;
		Delay0000=1;
		InitCommand=function(self)
			if Reverse then
				self:blend("BlendMode_Add")
				self:addy(-4.5)
				self:zoom(0.44444444)
				self:valign(1)
				self:diffusealpha(0)
			else
				self:blend("BlendMode_Add")
				self:addy(4.5)
				self:zoom(0.44444444)
				self:valign(1)
				self:diffusealpha(0)
				self:addrotationz(180)
			end
		end,
		PressCommand=function(self)
			self:stoptweening()
			self:accelerate(.05)
			self:diffusealpha(.8)
		end,
		LiftCommand=function(self)
			self:stoptweening()
			self:linear(.1)
			self:diffusealpha(0)
		end,
		NoneCommand=function(self)
		end
	};

--Stage Right
	Def.Sprite {
				Texture="Stage/right";
				Frame0000=0;
				Delay0000=1;
				--OnCommand instead of InitCommand in order to make the screen check work
				OnCommand=function(self)

					--Fade texture if outside gameplay/practice
					--mainly for song select and player options preview
					if SCREENMAN:GetTopScreen():GetName() == "ScreenGameplay" or SCREENMAN:GetTopScreen():GetName() == "ScreenGameplaySyncMachine" or SCREENMAN:GetTopScreen():GetName() == "ScreenGameplayPractice" then
						--No fade if in gameplay
						stageFade = 0
					else
						--Fade stage outside of gameplay
						--Mainly for song select and player options preview
						stageFade = 0.1
						--Mini is not applied outside gameplay, so let's just make this 1
						miniAdjustedScale = 1
					end


					if Reverse then
						self:halign(0.5)
						self:zoom(0.44444444 * miniAdjustedScale)
						self:diffusealpha(stageBorderActive)
						self:addx(32)
						self:addy(-163 * miniAdjustedScale)
						self:fadebottom(stageFade)
						self:fadetop(stageFade)
					else
						self:halign(0.5)
						self:zoom(0.44444444 * miniAdjustedScale)
						self:diffusealpha(stageBorderActive)
						self:addx(32)
						self:addy(163 * miniAdjustedScale)
						self:fadebottom(stageFade)
						self:fadetop(stageFade)
					end
				end,
			};

--Receptor button idle
	Def.Sprite {
		Texture="Stage/1 button";
		Frame0000=0;
		Delay0000=1;
		InitCommand=function(self)
			if Reverse then
				self:zoom(0.44444444)
				self:diffusealpha(stageButtonActive)
				self:addy(31)
			else
				self:zoom(0.44444444)
				self:diffusealpha(stageButtonActive)
				self:addy(-31)
				self:addrotationz(180)
			end
		end,
		PressCommand=function(self)
			self:diffusealpha(0)
			self:diffusealpha(0)
		end,
		LiftCommand=function(self)
			self:stoptweening()
			self:sleep(.032)
			self:diffusealpha(stageButtonActive)
		end,
		NoneCommand=function(self)
			self:diffusealpha(stageButtonActive)
		end
	};

--Receptor button pressed
	Def.Sprite {
		Texture="Stage/1 down button";
		Frame0000=0;
		Delay0000=1;
		InitCommand=function(self)
			if Reverse then
				self:zoom(0.44444444)
				self:diffusealpha(0)
				self:addy(31)
			else
				self:zoom(0.44444444)
				self:diffusealpha(0)
				self:addy(-31)
				self:addrotationz(180)
			end
		end,
		PressCommand=function(self)
			self:stoptweening()
			self:diffusealpha(stageButtonActive)
		end,
		LiftCommand=function(self)
			self:stoptweening()
			self:sleep(.032)
			self:diffusealpha(0)
		end,
		NoneCommand=function(self)
			self:diffusealpha(0)
		end
	};

--Judgeline
Def.Sprite {
		Texture="Stage/judgeline";
		Frame0000=0;
		Delay0000=1;
		InitCommand=function(self)
			if Reverse then
				self:halign(0)
				self:zoom(0.44444444)
				self:diffusealpha(1)
				self:addx(-224)
			else
				--Reversed alignment due to rotation
				self:halign(1)
				self:zoom(0.44444444)
				self:diffusealpha(1)
				self:addx(-224)
				self:addrotationz(180)
			end
		end,
	};

--Girl left
Def.Sprite {
		--leftGirl defined at the top 
		Texture=leftGirl;
		Frame0000=0;
		Delay0000=1;
		OnCommand=function(self)
			--Determine if girl is enabled
			if leftGirl ~= "off" then
				girlActive1 = 1
			else
				girlActive1 = 0
			end

			--Move girl down if iroha
			--She's higher up than the others
			if leftGirl == "iroha" or rightGirl == "iroha" then
				yOffset = 20
			else
				yOffset = 0
			end


			if SCREENMAN:GetTopScreen():GetName() == "ScreenGameplay" or SCREENMAN:GetTopScreen():GetName() == "ScreenGameplaySyncMachine" or SCREENMAN:GetTopScreen():GetName() == "ScreenGameplayPractice" then
			--xOffset is specifically for the left girl
			--In song select, there is a bit of overlap on note info in Til Death
			--In gameplay, mini will move the girl too much on the field. Let's compensate for that if mini is on
				girlFade = 0
				--This is so hard to position right
				--It doesn't align well on aggressive mini but I guess it's better than nothing !!
				if rawMini > 0 then
					xOffset = -45 * rawMini
				else
					xOffset = 0
				end
			else
				girlFade = 0.4
				xOffset = 10
				miniAdjustedScale = 1
			end

			if Reverse then
				self:zoom(0.44444444 * miniAdjustedScale)
				self:diffusealpha(girlActive1)
				self:addx(-256)
				self:addy(miniAdjustedScale * (-44 + yOffset))
				self:addx(xOffset)
				self:fadebottom(girlFade)
			else
				self:zoom(0.44444444 * miniAdjustedScale)
				self:diffusealpha(girlActive1)
				self:addx(-256)
				self:addy(miniAdjustedScale * (284 + yOffset))
				self:addx(xOffset)
				self:fadebottom(girlFade)
			end
		end,
	};

--Girl right
Def.Sprite {
		--rightGirl defined at the top
		Texture=rightGirl;
		Frame0000=0;
		Delay0000=1;
		OnCommand=function(self)
			if rightGirl ~= "off" then
				girlActive2 = 1
			else
				girlActive2 = 0
			end

			if leftGirl == "iroha" or rightGirl == "iroha" then
				yOffset = 20
			else
				yOffset = 0
			end

			if SCREENMAN:GetTopScreen():GetName() == "ScreenGameplay" or SCREENMAN:GetTopScreen():GetName() == "ScreenGameplaySyncMachine" or SCREENMAN:GetTopScreen():GetName() == "ScreenGameplayPractice" then
				girlFade = 0
			else
				girlFade = 0.4
				miniAdjustedScale = 1
			end

			if Reverse then
				--Negative zoomx flips girl on the right side
				self:zoom(0.44444444 * miniAdjustedScale)
				self:zoomx(-0.44444444 * miniAdjustedScale)
				self:diffusealpha(girlActive2)
				self:addx(64 * miniAdjustedScale)
				self:addy(miniAdjustedScale * (-44 + yOffset))
				self:fadebottom(girlFade)
			else
				self:zoom(0.44444444 * miniAdjustedScale)
				self:zoomx(-0.44444444 * miniAdjustedScale)
				self:diffusealpha(girlActive2)
				self:addx(64 * miniAdjustedScale)
				self:addy(miniAdjustedScale * (284 + yOffset))
				self:fadebottom(girlFade)
			end
		end,
	};

};

return t;